@@ -1,4 +1,4 @@
-from appwashpy.client.appwash import AppWash
+from appwashpy.client.appwash import AppWash, check_credentials
 from appwashpy.core.location import Location
 from appwashpy.core.service import Service
 from appwashpy.common.enums import SERVICE_TYPE, LOCATION_TYPE, STATE
